@@ -47,4 +47,34 @@ float FirebaseMLKit::getHeadEulerAngleY()
 float FirebaseMLKit::getHeadEulerAngleZ()
 {
 	return m_firebaseMLKitImpl->GetHeadEulerAngleZ();
+}
+
+uint32_t FirebaseMLKit::getCameraWidth()
+{
+    return m_firebaseMLKitImpl->GetCameraWidth();
+}
+
+uint32_t FirebaseMLKit::getCameraHeight()
+{
+    return m_firebaseMLKitImpl->GetCameraHeight();
+}
+
+uint8_t* FirebaseMLKit::getCameraData()
+{
+    return m_firebaseMLKitImpl->GetCameraData();
+}
+
+void FirebaseMLKit::clearContourList()
+{
+	m_contourList.clear();
+}
+
+void FirebaseMLKit::addToContourList(uint32_t value)
+{
+	m_contourList.push_back(value);
+}
+
+std::vector<uint32_t> FirebaseMLKit::getContourList()
+{
+	return m_contourList;
 }
\ No newline at end of file
