@@ -25,7 +25,7 @@ PyObject* firebaseMLKit_str(firebaseMLKit_obj* self)
 
 static PyObject* firebaseMLKit_Init(firebaseMLKit_obj* self, PyObject* args)
 {
-	int mode = 0;	// 0 = FAST ; 1 = ACCURATE
+	int mode = 1;	// 1 = FAST ; 2 = ACCURATE
 	if (!PyArg_ParseTuple(args, "|i", &mode)) return NULL;
 
 	FirebaseMLKit::Instance()->init(mode);
@@ -61,6 +61,8 @@ static PyObject* firebaseMLKit_GetContours(firebaseMLKit_obj* self)
 	{
 		PyObject* obj = Py_BuildValue("(ff)", contours[i], contours[i+1]);
 		PyList_Append(list, obj);
+        
+        Py_XDECREF(obj);
 	}
 	return list;
 }
@@ -86,6 +88,44 @@ static PyObject* firebaseMLKit_isSupported(firebaseMLKit_obj* self)
 }
 
 
+static PyObject* firebaseMLKit_GetCameraSize(firebaseMLKit_obj* self)
+{
+    PyObject* cameraSize = Py_BuildValue("{s:i,s:i}",
+        "w", FirebaseMLKit::Instance()->getCameraWidth(),
+        "h", FirebaseMLKit::Instance()->getCameraHeight());
+    
+
+    return cameraSize;
+}
+
+static PyObject* firebaseMLKit_GetCameraData(firebaseMLKit_obj* self)
+{
+    uint8_t* result = FirebaseMLKit::Instance()->getCameraData();
+    PyObject* obj = PyBytes_FromStringAndSize((char*)result, FirebaseMLKit::Instance()->getCameraWidth() * FirebaseMLKit::Instance()->getCameraHeight() * 3);
+
+    return obj;
+}
+
+static PyObject* firebaseMLKit_SetContourList(firebaseMLKit_obj* self, PyObject* args)
+{
+	PyObject* contourList = nullptr;
+	if (!PyArg_ParseTuple(args, "O", &contourList)) return NULL;
+
+	if (contourList && PyList_Check(contourList))
+	{
+		FirebaseMLKit::Instance()->clearContourList();
+		int numAttr = (int)PyList_Size(contourList);
+		for (int i = 0; i < numAttr; i++)
+		{
+			PyObject* val = PyList_GET_ITEM(contourList, i);
+			FirebaseMLKit::Instance()->addToContourList((uint32_t)PyLong_AsLong(val));
+		}
+	}
+
+	Py_INCREF(Py_None);
+	return Py_None;
+}
+
 PyMethodDef firebaseMLKit_methods[] = {
 	{ "isSupported", (PyCFunction)firebaseMLKit_isSupported, METH_NOARGS, firebaseMLKitIsSupported_doc },
 	{ "init", (PyCFunction)firebaseMLKit_Init, METH_VARARGS, firebaseMLKitInit_doc },
@@ -93,6 +133,9 @@ PyMethodDef firebaseMLKit_methods[] = {
 	{ "preview", (PyCFunction)firebaseMLKit_Preview, METH_NOARGS, firebaseMLKitPreview_doc },
 	{ "getContours", (PyCFunction)firebaseMLKit_GetContours, METH_NOARGS, firebaseMLKitGetContours_doc },
 	{ "getHeadEulerAngle", (PyCFunction)firebaseMLKit_getHeadEulerAngle, METH_NOARGS, firebaseMLKitGetHeadEulerAngle_doc },
+    { "getCameraSize", (PyCFunction)firebaseMLKit_GetCameraSize, METH_NOARGS, cameraGetCameraSize_doc },
+    { "getCameraData", (PyCFunction)firebaseMLKit_GetCameraData, METH_NOARGS, cameraGetCameraData_doc },
+	{ "setContourList", (PyCFunction)firebaseMLKit_SetContourList, METH_VARARGS, firebaseMLKitSetContourList_doc },
 	{ NULL,	NULL }
 };
 
@@ -140,4 +183,4 @@ PyTypeObject FirebaseMLKitType = {
 	0,											/* tp_alloc */
 	firebaseMLKit_new,							/* tp_new */
 	0,											/* tp_free */
-};
\ No newline at end of file
+};
