@@ -3,6 +3,9 @@
 #include "firebase/app.h"
 #include "firebase/future.h"
 #include "firebase/remote_config.h"
+#include "firebase/firestore.h"
+#include "firebase/util.h"
+
 #include "FirebaseAnalytics.h"
 #include "FirebaseRemoteConfig.h"
 
@@ -24,6 +27,9 @@
 #include "json.hpp"
 using json = nlohmann::json;
 
+using firebase::App;
+using firebase::firestore::Firestore;
+
 void FirebaseLogMessage(const char* format, ...) {
 	va_list list;
 	va_start(list, format);
@@ -40,6 +46,10 @@ FirebaseImpl::FirebaseImpl()
 		, m_messageInitializer(nullptr)
 		, m_remoteConfigInitializer(nullptr)
         , m_isReady(false)
+		, m_isAnalytics(false)
+		, m_isMessaging(false)
+		, m_isRemoteConfig(false)
+		, m_isFirestore(false)
 {
 #if defined(_WIN32)
 	QueryPerformanceFrequency(&freq);
@@ -52,17 +62,49 @@ FirebaseImpl::~FirebaseImpl()
 {
 }
 
+void FirebaseImpl::WaitForFutureCompletion(firebase::FutureBase future, firebase::FutureStatus toCheck, int msec, double timeout)
+{
+	double time = GetTime();
+	while (ProcessEvents(msec))
+	{
+		double elapsedTime = GetTime() - time;
+		if (future.status() != firebase::kFutureStatusPending || elapsedTime > timeout)
+		{
+			break;
+		}
+	}
+}
+
+double FirebaseImpl::GetTime()
+{
+#if defined(_WIN32)
+	static LARGE_INTEGER cuurentTime;
+	QueryPerformanceCounter(&cuurentTime);
+	return (double)cuurentTime.QuadPart / (double)freq.QuadPart;
+#elif defined __ANDROID__
+	struct timespec tv;
+	clock_gettime(CLOCK_MONOTONIC, &tv);
+	return (double)tv.tv_sec + (double)tv.tv_nsec / 1000000000.0;
+#else
+	uint64_t t = mach_absolute_time();
+	double tsec = (double)t * (double)timebase.numer / (double)timebase.denom / 1000000000.0;
+	return tsec;
+#endif
+}
+
 bool FirebaseImpl::ProcessEvents(int msec)
 {
     Sleep(msec);
     return false;
 }
 
-void FirebaseImpl::Init(bool analytics, bool messaging, bool remoteConfig)
+void FirebaseImpl::Init(bool analytics, bool messaging, bool remoteConfig, bool firestore)
 {
-	m_analytics = analytics;
-	m_messaging = messaging;
-	m_remoteConfig = remoteConfig;
+	m_isAnalytics = analytics;
+	m_isMessaging = messaging;
+	m_isRemoteConfig = remoteConfig;
+	m_isFirestore = firestore;
+
     // app
     Firebase::firebase_app = ::firebase::App::GetInstance();
     if(Firebase::firebase_app == nullptr)
@@ -71,23 +113,29 @@ void FirebaseImpl::Init(bool analytics, bool messaging, bool remoteConfig)
     }
 
 	// analytics
-	if (m_analytics)
+	if (m_isAnalytics)
 	{
 		AnalyticsInit();
 	}
 
 	// messaging
-	if (m_messaging)
+	if (m_isMessaging)
 	{
 		MessagingInit();
 	}
 
 	// remote config
-	if (m_remoteConfig)
+	if (m_isRemoteConfig)
 	{
 		RemoteConfigInit();
 	}
 
+	// firestore
+	if (m_isFirestore)
+	{
+		FirestoreInit();
+	}
+
     m_isReady = true;
 }
 
@@ -95,20 +143,25 @@ void FirebaseImpl::Release()
 {
     m_isReady = false;
     
-	if (m_analytics)
+	if (m_isAnalytics)
 	{
 		AnalyticsRelease();
 	}
 
-	if (m_messaging)
+	if (m_isMessaging)
 	{
 		MessagingRelease();
 	}
 
-	if (m_remoteConfig)
+	if (m_isRemoteConfig)
 	{
 		RemoteConfigRelease();
 	}
+
+	if (m_isFirestore)
+	{
+		FirestoreRelease();
+	}
 }
 
 void FirebaseImpl::AnalyticsInit()
@@ -267,32 +320,34 @@ void FirebaseImpl::RemoteConfigFetchAll()
 	}
 }
 
-void FirebaseImpl::WaitForFutureCompletion(firebase::FutureBase future, firebase::FutureStatus toCheck, int msec, double timeout)
+void FirebaseImpl::FirestoreInit()
 {
-    double time = GetTime();
-    while (ProcessEvents(msec))
-    {
-        double elapsedTime = GetTime() - time;
-        if (future.status() != firebase::kFutureStatusPending || elapsedTime > timeout)
-        {
-            break;
-        }
+    firebase::InitResult result;
+    firebase::auth::Auth* auth = firebase::auth::Auth::GetAuth(Firebase::firebase_app, &result);
+    if (result != firebase::kInitResultSuccess) {
+        LOG("Failed to initialize Firebase Auth, error: %d", static_cast<int>(result));
+        return;
     }
+    auto future_login = auth->SignInAnonymously();
+    WaitForFutureCompletion(future_login);
+    auto* future_login_result = future_login.result();
+    if (future_login_result && *future_login_result) {
+        m_user = *future_login_result;
+        LOG("Signed in uid: %s", m_user->uid().c_str());
+    } else {
+        LOG("ERROR: could not sign in");
+    }
+    future_login.Release();
+
 }
 
-double FirebaseImpl::GetTime()
+void FirebaseImpl::FirestoreRelease()
 {
-#if defined(_WIN32)
-	static LARGE_INTEGER cuurentTime;
-	QueryPerformanceCounter(&cuurentTime);
-	return (double)cuurentTime.QuadPart / (double)freq.QuadPart;
-#elif defined __ANDROID__
-	struct timespec tv;
-	clock_gettime(CLOCK_MONOTONIC, &tv);
-	return (double)tv.tv_sec + (double)tv.tv_nsec / 1000000000.0;
-#else
-	uint64_t t = mach_absolute_time();
-	double tsec = (double)t * (double)timebase.numer / (double)timebase.denom / 1000000000.0;
-	return tsec;
-#endif
+}
+
+std::string FirebaseImpl::GetUserUID()
+{
+	if(IsAuthenticated())
+		return m_user->uid();
+	return "";
 }
\ No newline at end of file
