@@ -34,4 +34,19 @@ float FirebaseMLKitImpl::GetHeadEulerAngleZ()
 float* FirebaseMLKitImpl::GetContours(int& size)
 {
 	return {};
+}
+
+uint8_t* FirebaseMLKitImpl::GetCameraData()
+{
+	return {};
+}
+
+int FirebaseMLKitImpl::GetCameraWidth()
+{
+	return 0;
+}
+
+int FirebaseMLKitImpl::GetCameraHeight()
+{
+	return 0;
 }
\ No newline at end of file
